@@ -1,63 +1,59 @@
 STRICTDOC_BASIC_TYPE_SYSTEM = r"""
-FieldName[noskipws]:
-  /[A-Z]+[A-Z_]*/
+BooleanChoice[noskipws]:
+  ('True' | 'False')
 ;
 
-SingleLineString:
-  (!MultiLineStringStart /./)*
+ChoiceOption[noskipws]:
+  /[\w\/|-]+( *[\w\/|-]+)*/
 ;
 
-MultiLineStringStart[noskipws]:
-  '>>>' '\n'
+ChoiceOptionXs[noskipws]:
+  /, /- ChoiceOption
 ;
 
-MultiLineStringEnd[noskipws]:
-  '<<<'
+RequirementType[noskipws]:
+  !ReservedKeyword /[A-Z]+(_[A-Z]+)*/
 ;
 
-MultiLineString[noskipws]:
-  MultiLineStringStart-
-  ((!MultiLineStringEnd /(?ms)./)+ | '')
-  MultiLineStringEnd-
+ReservedKeyword[noskipws]:
+  'DOCUMENT' | 'GRAMMAR'
 ;
 
 Reference[noskipws]:
   // FileReference is an early, experimental feature. Do not use yet.
-  ParentReqReference | FileReference | BibReference
+  ParentReqReference | ChildReqReference | FileReference
 ;
 
 ParentReqReference[noskipws]:
   '- TYPE: Parent' '\n'
   '  VALUE: ' ref_uid = /.*$/ '\n'
+  ('  ROLE: ' role = /.+$/ '\n')?
 ;
 
+ChildReqReference[noskipws]:
+  '- TYPE: Child' '\n'
+  '  VALUE: ' ref_uid = /.*$/ '\n'
+  ('  ROLE: ' role = /.+$/ '\n')?
+;
+
+
 FileReference[noskipws]:
   // FileReference is an early, experimental feature. Do not use yet.
   '- TYPE: File' '\n'
+  ('  ROLE: ' role = /.+$/ '\n')?
   g_file_entry = FileEntry
 ;
 
 FileEntry[noskipws]:
   ('  FORMAT: ' g_file_format = FileEntryFormat '\n')?
    '  VALUE: ' g_file_path = /.*$/ '\n'
+  ('  LINE_RANGE: ' g_line_range = /.*$/ '\n')?
+  ('  FUNCTION: ' function = /.*$/ '\n')?
+  ('  CLASS: ' clazz = /.*$/ '\n')?
 ;
 
 FileEntryFormat[noskipws]:
   'Sourcecode' | 'Python' | /[A-Z]+[A-Z_]*/
 ;
 
-BibReference[noskipws]:
-  '- TYPE: BibRef' '\n'
-  bib_entry = BibEntry
-;
-
-BibEntry[noskipws]:
-  ('  FORMAT: ' bib_format = BibEntryFormat '\n')?
-   '  VALUE: ' bib_value = /.*$/ '\n'
-;
-
-BibEntryFormat[noskipws]:
-  'String' | 'BibTex' | 'Citation'
-;
-
 """
