@@ -170,9 +170,6 @@ class SDocDocument(SDocDocumentIF):
     def uid(self) -> Optional[str]:
         return self.config.uid
 
-    def is_section(self) -> bool:
-        return True
-
     @property
     def is_root_included_document(self) -> bool:
         return self.document_is_included()
@@ -180,6 +177,9 @@ class SDocDocument(SDocDocumentIF):
     def is_requirement(self) -> bool:
         return False
 
+    def is_document(self) -> bool:
+        return True
+
     def get_display_node_type(self) -> str:
         return "Document"
 
