@@ -21,7 +21,6 @@ from strictdoc.backend.sdoc.models.model import (
     SDocDocumentIF,
     SDocElementIF,
     SDocNodeIF,
-    SDocSectionIF,
 )
 from strictdoc.backend.sdoc.models.reference import (
     ChildReqReference,
@@ -103,7 +102,7 @@ class SDocNodeField:
 class SDocNode(SDocNodeIF):
     def __init__(
         self,
-        parent: Union[SDocDocumentIF, SDocSectionIF, SDocNodeIF],
+        parent: Union[SDocDocumentIF, SDocNodeIF],
         node_type: str,
         fields: List[SDocNodeField],
         relations: List[Reference],
@@ -116,7 +115,7 @@ class SDocNode(SDocNodeIF):
         assert isinstance(node_type, str)
         assert isinstance(relations, list), relations
 
-        self.parent: Union[SDocDocumentIF, SDocSectionIF, SDocNodeIF] = parent
+        self.parent: Union[SDocDocumentIF, SDocNodeIF] = parent
 
         self.node_type: str = node_type
 
@@ -238,21 +237,26 @@ class SDocNode(SDocNodeIF):
     def get_node_type_string(self) -> Optional[str]:
         return self.node_type
 
-    def get_display_node_type_string(self) -> Optional[str]:
-        if self.is_composite:
-            return f"[[{self.node_type}]]"
-        return f"[{self.node_type}]"
-
     def get_display_title(
         self,
         include_toc_number: bool = True,  # noqa: ARG002
     ) -> str:
         if self.reserved_title is not None:
+            if (
+                include_toc_number
+                and self.context.title_number_string is not None
+            ):
+                return (
+                    f"{self.context.title_number_string}. {self.reserved_title}"
+                )
             return self.reserved_title
         if self.reserved_uid is not None:
             return self.reserved_uid
         if self.node_type == "TEXT":
-            if isinstance(self.parent, SDocSectionIF):
+            if (
+                isinstance(self.parent, SDocNode)
+                and self.parent.node_type == "SECTION"
+            ):
                 return f'Text node from section "{self.parent.get_display_title()}"'
             if isinstance(self.parent, SDocDocumentIF):
                 return f'Text node from document "{self.parent.get_display_title()}"'
@@ -364,9 +368,6 @@ class SDocNode(SDocNodeIF):
     def is_text_node(self) -> bool:
         return self.node_type == "TEXT"
 
-    def is_section(self) -> bool:
-        return False
-
     def is_document(self) -> bool:
         return False
 
@@ -771,7 +772,7 @@ class SDocNode(SDocNodeIF):
 class SDocCompositeNode(SDocNode):
     def __init__(
         self,
-        parent: Union[SDocDocumentIF, SDocSectionIF, SDocNodeIF],
+        parent: Union[SDocDocumentIF, SDocNodeIF],
         **fields: Any,
     ) -> None:
         super().__init__(parent, **fields, is_composite=True)
