@@ -2,7 +2,6 @@
 @relation(SDOC-SRS-142, scope=file)
 """
 
-# mypy: disable-error-code="no-untyped-call"
 from functools import partial
 from typing import Any, Dict, List, Optional, TypedDict
 
@@ -22,7 +21,12 @@ from strictdoc.backend.sdoc_source_code.models.source_file_info import (
     SourceFileTraceabilityInfo,
 )
 from strictdoc.backend.sdoc_source_code.parse_context import ParseContext
+from strictdoc.backend.sdoc_source_code.processors.general_language_marker_processors import (
+    line_marker_processor,
+    validate_marker_uids,
+)
 from strictdoc.helpers.file_stats import SourceFileStats
+from strictdoc.helpers.file_system import file_open_read_utf8
 from strictdoc.helpers.textx import drop_textx_meta
 
 
@@ -140,6 +144,8 @@ def create_unmatch_range_error(
 def range_marker_processor(
     marker: RangeMarker, parse_context: ParseContext
 ) -> None:
+    validate_marker_uids(marker, parse_context)
+
     location = get_location(marker)
     line = location["line"]
 
@@ -196,32 +202,11 @@ def range_marker_processor(
         raise NotImplementedError
 
 
-def line_marker_processor(
-    line_marker: LineMarker, parse_context: ParseContext
-) -> None:
-    location = get_location(line_marker)
-    line = location["line"]
-
-    if (
-        len(parse_context.marker_stack) > 0
-        and parse_context.marker_stack[-1].ng_is_nodoc
-    ):
-        # This marker is within a "nosdoc" block, so we ignore it.
-        return
-
-    parse_context.markers.append(line_marker)
-    line_marker.ng_source_line_begin = line
-    line_marker.ng_range_line_begin = line
-    line_marker.ng_range_line_end = line
-
-    for req in line_marker.reqs:
-        markers = parse_context.map_reqs_to_markers.setdefault(req, [])
-        markers.append(line_marker)
-
-
 def function_range_marker_processor(
     function_range_marker: FunctionRangeMarker, parse_context: ParseContext
 ) -> None:
+    validate_marker_uids(function_range_marker, parse_context)
+
     if (
         len(parse_context.marker_stack) > 0
         and parse_context.marker_stack[-1].ng_is_nodoc
@@ -308,7 +293,7 @@ class SourceFileTraceabilityReader:
         return source_file_traceability_info
 
     def read_from_file(self, file_path: str) -> SourceFileTraceabilityInfo:
-        with open(file_path, encoding="utf-8") as file:
+        with file_open_read_utf8(file_path) as file:
             sdoc_content = file.read()
             sdoc = self.read(sdoc_content, file_path=file_path)
             return sdoc
