@@ -9,12 +9,10 @@ from strictdoc.backend.sdoc.models.model import (
     SDocElementIF,
     SDocIteratedElementIF,
     SDocNodeIF,
-    SDocSectionIF,
 )
 from strictdoc.backend.sdoc.models.node import (
     SDocNode,
 )
-from strictdoc.backend.sdoc.models.section import SDocSection
 from strictdoc.helpers.cast import assert_cast
 
 
@@ -88,8 +86,14 @@ class DocumentCachingIterator:
         print_fragments: bool = False,
         level_stack: Tuple[int, ...] = (),
         custom_level: bool = False,
+        update_levels: bool = True,
     ) -> Iterator[Tuple[SDocIteratedElementIF, DocumentIterationContext]]:
-        if isinstance(node, SDocSection):
+        """
+        FIXME: update_levels is hack. Change the design so that the node state
+               is not patched during the iteration.
+        """
+
+        if isinstance(node, SDocNode):
             # If node is not whitelisted, we ignore it. Also, note that due to
             # this early return, all child nodes of this node are ignored
             # as well because they are not added to the iteration queue.
@@ -100,49 +104,9 @@ class DocumentCachingIterator:
             context = DocumentIterationContext(
                 node, level_stack, custom_level=custom_level
             )
-            node.context.title_number_string = context.get_level_string()
-            node.ng_level = context.get_level()
-
-            yield node, context
-
-            current_number = 0
-            for subnode_ in node.section_contents:
-                if subnode_.ng_resolved_custom_level is None and not (
-                    isinstance(subnode_, SDocNode)
-                    and subnode_.node_type == "TEXT"
-                    and subnode_.reserved_title is None
-                ):
-                    current_number += 1
-
-                yield from self.all_node_content(
-                    assert_cast(
-                        subnode_,
-                        (
-                            SDocNodeIF,
-                            SDocSectionIF,
-                            SDocDocumentIF,
-                            SDocDocumentFromFileIF,
-                        ),
-                    ),
-                    print_fragments=print_fragments,
-                    level_stack=level_stack + (current_number,),
-                    custom_level=custom_level
-                    or subnode_.ng_resolved_custom_level is not None,
-                )
-
-        elif isinstance(node, SDocNode):
-            # If node is not whitelisted, we ignore it. Also, note that due to
-            # this early return, all child nodes of this node are ignored
-            # as well because they are not added to the iteration queue.
-            if not node.ng_whitelisted:
-                return
-
-            # FIXME: This will be changed to yield only context.
-            context = DocumentIterationContext(
-                node, level_stack, custom_level=custom_level
-            )
-            node.context.title_number_string = context.get_level_string()
-            node.ng_level = context.get_level()
+            if update_levels:
+                node.context.title_number_string = context.get_level_string()
+                node.ng_level = context.get_level()
 
             yield node, context
 
@@ -161,6 +125,7 @@ class DocumentCachingIterator:
                         level_stack=level_stack + (current_number,),
                         custom_level=custom_level
                         or subnode_.ng_resolved_custom_level is not None,
+                        update_levels=update_levels,
                     )
 
         elif isinstance(node, SDocDocument):
@@ -172,8 +137,11 @@ class DocumentCachingIterator:
                 context = DocumentIterationContext(
                     node, level_stack, custom_level=custom_level
                 )
-                node.context.title_number_string = context.get_level_string()
-                node.ng_level = context.get_level()
+                if update_levels:
+                    node.context.title_number_string = (
+                        context.get_level_string()
+                    )
+                    node.ng_level = context.get_level()
 
                 yield node, context
 
@@ -189,7 +157,6 @@ class DocumentCachingIterator:
                         subnode_,
                         (
                             SDocNodeIF,
-                            SDocSectionIF,
                             SDocDocumentIF,
                             SDocDocumentFromFileIF,
                         ),
@@ -198,6 +165,7 @@ class DocumentCachingIterator:
                     level_stack=level_stack + (current_number,),
                     custom_level=custom_level
                     or subnode_.ng_resolved_custom_level is not None,
+                    update_levels=update_levels,
                 )
 
         elif isinstance(node, DocumentFromFile):
@@ -210,6 +178,7 @@ class DocumentCachingIterator:
                 node.resolved_document,
                 print_fragments=print_fragments,
                 level_stack=level_stack,
+                update_levels=update_levels,
             )
 
         else:
