@@ -2,8 +2,7 @@
 @relation(SDOC-SRS-36, scope=file)
 """
 
-# mypy: disable-error-code="no-untyped-call,operator"
-import os
+# mypy: disable-error-code="operator"
 from pathlib import Path
 from typing import List, Tuple, Union
 
@@ -45,7 +44,7 @@ from strictdoc.export.html.html_templates import HTMLTemplates
 from strictdoc.export.html.renderers.link_renderer import LinkRenderer
 from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 from strictdoc.helpers.cast import assert_cast
-from strictdoc.helpers.file_modification_time import get_file_modification_time
+from strictdoc.helpers.file_system import file_open_read_utf8
 from strictdoc.helpers.timing import measure_performance
 
 
@@ -58,12 +57,8 @@ class SourceFileViewHTMLGenerator:
         traceability_index: TraceabilityIndex,
         html_templates: HTMLTemplates,
     ) -> None:
-        if os.path.isfile(source_file.output_file_full_path) and (
-            get_file_modification_time(source_file.full_path)
-            < get_file_modification_time(source_file.output_file_full_path)
-            and not traceability_index.file_dependency_manager.must_generate(
-                source_file.full_path
-            )
+        if not traceability_index.file_dependency_manager.must_generate(
+            source_file.output_file_full_path
         ):
             with measure_performance(
                 f"Skip: {source_file.in_doctree_source_file_rel_path}"
@@ -95,7 +90,7 @@ class SourceFileViewHTMLGenerator:
         traceability_index: TraceabilityIndex,
         html_templates: HTMLTemplates,
     ) -> Markup:
-        with open(source_file.full_path, encoding="utf-8") as opened_file:
+        with file_open_read_utf8(source_file.full_path) as opened_file:
             source_file_lines = opened_file.readlines()
 
         pygmented_source_file_lines: List[SourceLineEntry] = []
