@@ -1,9 +1,12 @@
-# mypy: disable-error-code="arg-type,no-untyped-call,union-attr"
+import importlib
 import os
+import sys
+from collections import defaultdict
 from functools import partial
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
+import orjson
 from html2pdf4doc.html2pdf4doc import PATH_TO_HTML2PDF4DOC_JS
 
 from strictdoc.backend.sdoc.models.document import SDocDocument
@@ -48,12 +51,16 @@ from strictdoc.export.html.html_templates import HTMLTemplates
 from strictdoc.export.html.renderers.link_renderer import LinkRenderer
 from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 from strictdoc.export.html.tools.html_embedded import HTMLEmbedder
+from strictdoc.features.tree_map.generator import TreeMapGenerator
+from strictdoc.helpers.cast import assert_cast
+from strictdoc.helpers.exception import StrictDocException
 from strictdoc.helpers.file_modification_time import get_file_modification_time
 from strictdoc.helpers.file_system import sync_dir
 from strictdoc.helpers.git_client import GitClient
+from strictdoc.helpers.mid import MID
 from strictdoc.helpers.parallelizer import Parallelizer
 from strictdoc.helpers.paths import SDocRelativePath
-from strictdoc.helpers.timing import measure_performance
+from strictdoc.helpers.timing import measure_performance, timing_decorator
 
 
 class HTMLGenerator:
@@ -81,6 +88,11 @@ class HTMLGenerator:
             export_output_html_root=self.project_config.export_output_html_root,
         )
 
+        # Export static search index.
+        self.export_static_html_search_index(
+            traceability_index=traceability_index
+        )
+
         # Export all documents in parallel.
         export_binding = partial(
             self.export_single_document_with_performance,
@@ -99,9 +111,34 @@ class HTMLGenerator:
             for document_ in traceability_index.document_tree.document_list:
                 if document_.document_is_included():
                     continue
+
+                document_meta = assert_cast(document_.meta, DocumentMeta)
+
+                input_doc_full_path = document_meta.input_doc_full_path
+                output_doc_full_path = document_meta.output_document_full_path
+
+                if os.path.isfile(output_doc_full_path) and (
+                    get_file_modification_time(input_doc_full_path)
+                    < get_file_modification_time(output_doc_full_path)
+                    and not traceability_index.file_dependency_manager.must_generate(
+                        document_meta.output_document_full_path
+                    )
+                ):
+                    with measure_performance(f"Skip: {document_.title}"):
+                        continue
+
                 documents_to_export.append(document_)
 
-        parallelizer.run_parallel(documents_to_export, export_binding)
+        if len(documents_to_export) > 0:
+            if len(traceability_index.document_tree.document_list) <= 25:
+                parallelizer.run_parallel(documents_to_export, export_binding)
+            else:
+                print(  # noqa: T201
+                    "NOTE: Running document export without parallelization "
+                    "because the document tree contains more than 25 documents."
+                )
+                for document_ in documents_to_export:
+                    export_binding(document_)
 
         # Export document tree.
         # FIXME: It is important that this export is **after** the parallelized
@@ -113,6 +150,9 @@ class HTMLGenerator:
         # Export JavaScript map of the document tree (project map)
         self.export_project_map(traceability_index=traceability_index)
 
+        if self.project_config.is_activated_tree_map():
+            self.export_tree_map_screen(traceability_index)
+
         # Export project statistics.
         if self.project_config.is_feature_activated(
             ProjectFeature.PROJECT_STATISTICS_SCREEN
@@ -265,9 +305,12 @@ class HTMLGenerator:
 
         redundant_assets: Dict[str, List[SDocRelativePath]] = {}
         for document_ in traceability_index.document_tree.document_list:
+            assert document_.meta is not None
             for (
                 included_document_
             ) in document_.iterate_included_documents_depth_first():
+                assert included_document_.meta is not None
+
                 redundant_assets.setdefault(
                     document_.meta.input_doc_assets_dir_rel_path.relative_path_posix,
                     [],
@@ -276,6 +319,8 @@ class HTMLGenerator:
                     document_.meta.input_doc_assets_dir_rel_path.relative_path_posix
                 ].append(included_document_.meta.input_doc_assets_dir_rel_path)
 
+        assert traceability_index.asset_manager is not None
+
         asset_dir_: AssetDir
         for asset_dir_ in traceability_index.asset_manager.iterate():
             source_path = asset_dir_.full_path
@@ -319,18 +364,6 @@ class HTMLGenerator:
         if specific_documents is None:
             specific_documents = DocumentType.all()
 
-        input_doc_full_path = document.meta.input_doc_full_path
-        output_doc_full_path = document.meta.output_document_full_path
-
-        if os.path.isfile(output_doc_full_path) and (
-            get_file_modification_time(input_doc_full_path)
-            < get_file_modification_time(output_doc_full_path)
-            and not traceability_index.file_dependency_manager.must_generate(
-                document.meta.input_doc_full_path
-            )
-        ):
-            with measure_performance(f"Skip: {document.title}"):
-                return
         with measure_performance(f"Published: {document.title}"):
             self.export_single_document(
                 document,
@@ -583,11 +616,49 @@ class HTMLGenerator:
         self,
         traceability_index: TraceabilityIndex,
     ) -> None:
+        """
+        Export project statistics to a dedicated HTML page.
+
+        @relation(SDOC-SRS-97, scope=function)
+        @relation(SDOC-SRS-154, scope=function)
+        """
+
         link_renderer = LinkRenderer(
             root_path="",
             static_path=self.project_config.dir_for_sdoc_assets,
         )
-        document_content = ProgressStatisticsGenerator.export(
+
+        statistics_generator = ProgressStatisticsGenerator
+
+        if (
+            custom_statistics_generator_path
+            := self.project_config.statistics_generator
+        ) is not None:
+            # It is important to add the input folder to the import path.
+            # Otherwise, the custom statistics generator may not be found.
+            # In fact, a more reasonable path to add would be the project config
+            # path, but since it is not maintained by ProjectConfig yet and
+            # usually equals the input path, add the input path for
+            # now.
+            input_paths = self.project_config.input_paths
+            assert input_paths is not None and len(input_paths) > 0, (
+                "Expected a valid input path."
+            )
+            sys.path.insert(0, input_paths[0])
+
+            module_path, class_name = custom_statistics_generator_path.rsplit(
+                ".", 1
+            )
+            try:
+                module = importlib.import_module(module_path)
+                statistics_generator = getattr(module, class_name)
+            except ModuleNotFoundError as module_not_found_error_:
+                raise StrictDocException(
+                    "Could not import a user-provided statistics generator: "
+                    f"{module_not_found_error_}."
+                ) from module_not_found_error_
+
+        document_content = statistics_generator.export(
             self.project_config,
             traceability_index,
             link_renderer,
@@ -599,3 +670,141 @@ class HTMLGenerator:
         )
         with open(output_html_source_coverage, "w", encoding="utf8") as file:
             file.write(document_content)
+
+    @timing_decorator("Export static HTML search index")
+    def export_static_html_search_index(
+        self,
+        traceability_index: TraceabilityIndex,
+    ) -> None:
+        """
+        Export a static search index as dictionaries in .js files.
+
+        @relation(SDOC-SRS-155, scope=function)
+        @relation(SDOC-SRS-156, scope=function)
+        """
+
+        # First check if there is nothing to do because no documents have been
+        # changed or regenerated.
+        for document_ in traceability_index.document_tree.document_list:
+            assert document_.meta is not None
+            if traceability_index.file_dependency_manager.must_generate(
+                document_.meta.output_document_full_path
+            ):
+                break
+        else:
+            print(  # noqa: T201
+                "All documents are up-to-date. "
+                "Skipping the generation of a search index."
+            )
+            # If no documents need to be regenerated, set the search_index_timestamp
+            # to the timestamp of the first document. The assumption here is
+            # that StrictDoc does not randomize the document list, and the first
+            # document will always be the same.
+            # The HTML/JS code can rely on this timestamp to decide whether it
+            # has to re-read the search index from the JS file or it can simply
+            # fetch it from the DB which is 2x faster when it comes to very
+            # large indexes.
+            if len(traceability_index.document_tree.document_list) > 0:
+                first_document = traceability_index.document_tree.document_list[
+                    0
+                ]
+                assert first_document.meta is not None
+                traceability_index.search_index_timestamp = (
+                    get_file_modification_time(
+                        first_document.meta.input_doc_full_path
+                    )
+                )
+            return
+
+        global_index: Dict[str, Set[int]] = defaultdict(set)
+        global_map_nodes_by_mid: Dict[int, Dict[str, str]] = {}
+
+        document_index_list: List[Dict[str, Set[str]]] = []
+        document_map_list: List[Dict[int, Dict[str, str]]] = []
+
+        map_mid_to_numbers: Dict[str, int] = {}
+
+        with measure_performance("Build search index"):
+            for document_ in traceability_index.document_tree.document_list:
+                assert document_.meta is not None
+                document_index_list.append(
+                    document_.search_index.document_index
+                )
+                map_nodes_by_numbers: Dict[int, Dict[str, str]] = {}
+                for (
+                    node_mid_,
+                    node_dict_,
+                ) in document_.search_index.map_nodes_by_mid.items():
+                    if node_mid_ not in map_mid_to_numbers:
+                        map_mid_to_numbers[node_mid_] = (
+                            len(map_mid_to_numbers) + 1
+                        )
+                    document_mid_number = map_mid_to_numbers[node_mid_]
+                    assert isinstance(document_mid_number, int)
+                    map_nodes_by_numbers[document_mid_number] = node_dict_
+
+                document_map_list.append(map_nodes_by_numbers)
+            for document_index_ in document_index_list:
+                for term_, document_mids_ in document_index_.items():
+                    document_mid_numbers = set()
+                    for document_mid_ in document_mids_:
+                        document_mid_number = map_mid_to_numbers[document_mid_]
+                        document_mid_numbers.add(document_mid_number)
+                    global_index[term_].update(document_mid_numbers)
+            for map_nodes_by_mid_ in document_map_list:
+                global_map_nodes_by_mid.update(map_nodes_by_mid_)
+
+        link_renderer = LinkRenderer(
+            root_path="",
+            static_path=self.project_config.dir_for_sdoc_assets,
+        )
+        for _, node_ in global_map_nodes_by_mid.items():
+            node = traceability_index.get_node_by_mid(MID(node_["MID"]))
+            node_["_LINK"] = link_renderer.render_local_anchor(node)
+
+        def default(obj: Any) -> Any:
+            if isinstance(obj, set):
+                return list(obj)
+            raise TypeError
+
+        with measure_performance("Serialize search index to JS"):
+            document_content = (
+                b"window.SDOC_SEARCH_INDEX = "
+                + orjson.dumps(
+                    global_index,
+                    option=orjson.OPT_NON_STR_KEYS,
+                    default=default,
+                )
+                + b";\n\n"
+            )
+
+        with measure_performance("Serialize lookup map {MID => node} to JS"):
+            document_content += (
+                b"window.SDOC_MAP_MID_TO_NODES = "
+                + orjson.dumps(
+                    global_map_nodes_by_mid, option=orjson.OPT_NON_STR_KEYS
+                )
+                + b";\n"
+            )
+
+        # Export StrictDoc's own assets.
+        output_html_static_files = os.path.join(
+            self.project_config.export_output_html_root,
+            self.project_config.dir_for_sdoc_assets,
+        )
+        output_html_source_coverage = os.path.join(
+            output_html_static_files,
+            "static_html_search_index.js",
+        )
+        with open(output_html_source_coverage, "wb") as file:
+            file.write(document_content)
+
+    def export_tree_map_screen(
+        self,
+        traceability_index: TraceabilityIndex,
+    ) -> None:
+        TreeMapGenerator.export(
+            project_config=self.project_config,
+            traceability_index=traceability_index,
+            html_templates=self.html_templates,
+        )
