@@ -1,9 +1,7 @@
-# mypy: disable-error-code="no-untyped-call,union-attr"
 import hashlib
 import io
 import os
 import re
-import sys
 from pathlib import Path
 from typing import Optional, Tuple
 
@@ -17,12 +15,16 @@ from strictdoc.core.project_config import ProjectConfig, ProjectFeature
 from strictdoc.export.rst.directives.raw_html_role import raw_html_role
 from strictdoc.export.rst.directives.sphinx_style_math import (
     MathDirective,
+    MathDirectiveForServer,
     eq_role,
+    eq_role_for_server,
     math_role,
+    math_role_for_server,
 )
 from strictdoc.export.rst.directives.wildcard_enhanced_image import (
     WildcardEnhancedImage,
 )
+from strictdoc.helpers.file_system import file_open_read_bytes
 
 
 class RstToHtmlFragmentWriter:
@@ -47,6 +49,7 @@ class RstToHtmlFragmentWriter:
         )
 
         if context_document is not None:
+            assert context_document.meta is not None
             WildcardEnhancedImage.current_reference_path = (
                 context_document.meta.output_document_dir_full_path
             )
@@ -70,9 +73,14 @@ class RstToHtmlFragmentWriter:
         self.context_document: Optional[SDocDocument] = context_document
 
         if project_config.is_feature_activated(ProjectFeature.MATHJAX):
-            directives.register_directive("math", MathDirective)
-            roles.register_canonical_role("math", math_role)
-            roles.register_canonical_role("eq", eq_role)
+            if project_config.is_running_on_server:
+                roles.register_canonical_role("eq", eq_role_for_server)
+                roles.register_canonical_role("math", math_role_for_server)
+                directives.register_directive("math", MathDirectiveForServer)
+            else:
+                roles.register_canonical_role("eq", eq_role)
+                roles.register_canonical_role("math", math_role)
+                directives.register_directive("math", MathDirective)
 
     def write(self, rst_fragment: str, use_cache: bool = True) -> Markup:
         assert isinstance(rst_fragment, str), rst_fragment
@@ -90,8 +98,8 @@ class RstToHtmlFragmentWriter:
         )
         if use_cache and os.path.isdir(path_to_rst_fragment_bucket_dir):
             if os.path.isfile(path_to_cached_fragment):
-                with open(
-                    path_to_cached_fragment, "rb"
+                with file_open_read_bytes(
+                    path_to_cached_fragment
                 ) as cached_fragment_file_:
                     return Markup(cached_fragment_file_.read().decode("UTF-8"))
         else:
@@ -121,7 +129,7 @@ class RstToHtmlFragmentWriter:
 
         output = publish_parts(
             rst_fragment,
-            writer_name="html",
+            writer="html",
             settings_overrides=settings,
             source_path=self.source_path,
         )
@@ -143,13 +151,13 @@ class RstToHtmlFragmentWriter:
                 )
             else:
                 error_message = f"RST markup syntax error: {warnings}"
-            print(  # noqa: T201
-                f"error: problems when converting RST to HTML:\n{error_message}"
+            final_message = (
+                f"problems when converting RST to HTML: {error_message}\n"
+                "RST fragment: >>>\n"
+                f"{rst_fragment}"
+                "<<<"
             )
-            print("RST fragment: >>>")  # noqa: T201
-            print(rst_fragment)  # noqa: T201
-            print("<<<")  # noqa: T201
-            sys.exit(1)
+            raise RuntimeError(final_message)
 
         html: str = output["html_body"]
 
@@ -168,7 +176,7 @@ class RstToHtmlFragmentWriter:
 
         try:
             output = publish_parts(
-                rst_fragment, writer_name="html", settings_overrides=settings
+                rst_fragment, writer="html", settings_overrides=settings
             )
             warnings = (
                 warning_stream.getvalue().rstrip("\n")
