@@ -1,5 +1,7 @@
 import hashlib
 
+from strictdoc.helpers.file_system import file_open_read_bytes
+
 
 def get_md5(obj: str) -> str:
     return hashlib.md5(obj.encode("utf-8")).hexdigest()
@@ -7,7 +9,7 @@ def get_md5(obj: str) -> str:
 
 def get_file_md5(path: str, buf_size: int = 65536) -> str:
     m = hashlib.md5()
-    with open(path, "rb") as f:
+    with file_open_read_bytes(path) as f:
         b = f.read(buf_size)
         while len(b) > 0:
             m.update(b)
